document.addEventListener('DOMContentLoaded', () => {
  const htmlInput = document.getElementById('htmlInput');
  const scrollOutput = document.getElementById('scrollOutput');
  const convertBtn = document.getElementById('convertBtn');
  const copyBtn = document.getElementById('copyBtn');

  function htmlToScroll(html) {
    // Remove comments
    html = html.replace(/<!--[\s\S]*?-->/g, '');
    
    // Basic conversions
    const conversions = {
      '<h1([^>]*)>(.*?)</h1>': 'h1 $2',
      '<h2([^>]*)>(.*?)</h2>': 'h2 $2',
      '<h3([^>]*)>(.*?)</h3>': 'h3 $2',
      '<p([^>]*)>(.*?)</p>': 'p $2',
      '<strong>(.*?)</strong>': '*$1*',
      '<em>(.*?)</em>': '_$1_',
      '<a href="([^"]*)"[^>]*>(.*?)</a>': 'link $2\n  $1',
      '<img src="([^"]*)"[^>]*>': 'image $1',
      '<ul[^>]*>([\s\S]*?)</ul>': (match, content) => {
        return content.replace(/<li[^>]*>([\s\S]*?)<\/li>/g, '- $1');
      },
      '<ol[^>]*>([\s\S]*?)</ol>': (match, content) => {
        return content.replace(/<li[^>]*>([\s\S]*?)<\/li>/g, '# $1');
      }
    };

    // Apply conversions
    let scroll = html;
    for (let [pattern, replacement] of Object.entries(conversions)) {
      const regex = new RegExp(pattern, 'g');
      if (typeof replacement === 'function') {
        scroll = scroll.replace(regex, replacement);
      } else {
        scroll = scroll.replace(regex, replacement);
      }
    }

    // Clean up
    scroll = scroll
      .replace(/\n\s*\n/g, '\n\n')  // Remove extra newlines
      .replace(/^\s+|\s+$/g, '')     // Trim whitespace
      .replace(/&nbsp;/g, ' ')       // Replace &nbsp;
      .replace(/&amp;/g, '&')        // Replace &amp;
      .replace(/&lt;/g, '<')         // Replace &lt;
      .replace(/&gt;/g, '>')         // Replace &gt;
      .replace(/&quot;/g, '"');      // Replace &quot;

    return scroll;
  }

  convertBtn.addEventListener('click', () => {
    const html = htmlInput.value;
    const scroll = htmlToScroll(html);
    scrollOutput.value = scroll;
  });

  copyBtn.addEventListener('click', async () => {
    try {
      await navigator.clipboard.writeText(scrollOutput.value);
      copyBtn.textContent = 'Copied!';
      setTimeout(() => {
        copyBtn.textContent = 'Copy';
      }, 2000);
    } catch (err) {
      console.error('Failed to copy text:', err);
    }
  });
});
